#
# spec file for package aMule
#
# Copyright (c) 2021 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           aMule
Version:        2.3.3.20210426.6d4c03b00
Release:        pm153.3.2
Summary:        Another eMule file-sharing program
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://www.amule.org
#https://github.com/amule-project/amule
Source:         %{name}-%{version}.tar.xz
BuildRequires:  binutils-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  man-pages-ro
BuildRequires:  mozilla-nspr
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-3_0-nostl-devel
%if ( 0%{?sle_version} == 150300 ||  0%{?sle_version} == 150400 ) && 0%{?is_opensuse}
BuildRequires:  libboost_headers1_75_0-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(cryptopp)
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libupnp)
Conflicts:      aMule-kde4

%description
aMule stand for another eMule file-sharing program, it is also
another fork of the xMule (former lMule) project. It connects
to eDonkey2000 network, supports Linux, *BSD platforms, and has
a new vision of the GUI.

%lang_package

%prep
%autosetup -p1
# remove shebang
sed -i '/^#!/d' src/utils/xas/xas.pl
#override version only for source 2.3.3.20210426.6d4c03b00
if [[ %version == 2.3.3.20210426.6d4c03b00 ]]; then
    sed -i '/VERSION "GIT"/s@.*@set (VERSION "2.3.3")\nset (SVNDATE "git 20210426")@' CMakeLists.txt
fi

%build
%cmake \
   -DBUILD_MONOLITHIC=ON \
   -DBUILD_DAEMON=ON \
   -DBUILD_AMULECMD=ON \
   -DBUILD_WEBSERVER=ON \
   -DBUILD_REMOTEGUI=ON \
   -DBUILD_CAS=ON \
   -DBUILD_WXCAS=ON \
   -DBUILD_ED2K=ON \
   -DBUILD_ALC=ON \
   -DBUILD_ALCC=ON \
   -DBUILD_XAS=ON \
   -DBUILD_FILEVIEW=ON \
   -DENABLE_UPNP=ON \
   -DCMAKE_BUILD_TYPE=Release \
   -DCMAKE_INSTALL_DOCDIR=%{_defaultdocdir}/%{name}
%cmake_build

%install
%cmake_install

%suse_update_desktop_file -G "P2P Client" -i amule Network P2P
%suse_update_desktop_file  %{buildroot}%{_datadir}/applications/alc.desktop
%suse_update_desktop_file  %{buildroot}%{_datadir}/applications/amulegui.desktop
%suse_update_desktop_file  %{buildroot}%{_datadir}/applications/wxcas.desktop

rm %{buildroot}%{_defaultdocdir}/%{name}/{INSTALL,license.txt}

%find_lang %{name} --all-name --with-man
%fdupes %{buildroot}

%files
%license docs/license.txt
%doc docs/AUTHORS
%doc %{_defaultdocdir}/*
%{_bindir}/alc
%{_bindir}/alcc
%{_bindir}/amule
%{_bindir}/amulecmd
%{_bindir}/amuled
%{_bindir}/amulegui
%{_bindir}/amuleweb
%{_bindir}/autostart-xas
%{_bindir}/cas
%{_bindir}/ed2k
%{_bindir}/fileview
%{_bindir}/wxcas
%dir %{_datadir}/amule
%{_datadir}/amule/skins
%{_datadir}/amule/webserver
%{_datadir}/applications/alc.desktop
%{_datadir}/applications/amule.desktop
%{_datadir}/applications/amulegui.desktop
%{_datadir}/applications/wxcas.desktop
%{_datadir}/cas
%{_datadir}/pixmaps/*.xpm
%dir %{_libdir}/xchat
%dir %{_libdir}/xchat/plugins
%{_libdir}/xchat/plugins/xas.pl
%{_mandir}/man1/alc.1%{?ext_man}
%{_mandir}/man1/alcc.1%{?ext_man}
%{_mandir}/man1/amule.1%{?ext_man}
%{_mandir}/man1/amulecmd.1%{?ext_man}
%{_mandir}/man1/amuled.1%{?ext_man}
%{_mandir}/man1/amulegui.1%{?ext_man}
%{_mandir}/man1/amuleweb.1%{?ext_man}
%{_mandir}/man1/cas.1%{?ext_man}
%{_mandir}/man1/ed2k.1%{?ext_man}
%{_mandir}/man1/wxcas.1%{?ext_man}
%{_mandir}/man1/xas.1%{?ext_man}

%files lang -f %{name}.lang
#only Leap 15.2/15.3 requires the next two lines
%dir %{_mandir}/tr
%dir %{_mandir}/ro

%changelog
* Sun Mar 27 2022 Giacomo Comes <gcomes.obs@gmail.com> - 2.3.3
- select boost 1.75 for leap 15.4
* Sun Nov 14 2021 Giacomo Comes <gcomes.obs@gmail.com> - 2.3.3
- add BuildRequires:  readline-devel
- add BuildRequires:  boost-devel
  * fix memory issue for version 2.3.3
  * select boost 1.75 for leap 15.3
- show correct version instead of GIT
- handle properly man pages translations tr and ro
* Mon Apr 26 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.3.3.20210426.6d4c03b00 (see Changelog for
  more details)
  * CMake support. CMake provides us platform-independent
    configuration files and generates native makefiles and
    workspaces for the compiler of your choice. It's highly
    experimental in its current state, but it aims to take the
    place of good old autoconf/automake one day.
  * Command completion with the TAB key in amulecmd.
  * Supports compilation with the latest C++ standard (C++17).
  * Scope graphs now (should) work on Mac.
  * Notification when a download completes.
  Requirements:
  * For UPnP you need at least libupnp-1.6.7.
  * For C++17 you need at least Cryptopp-6.0.0.
  * For notifications you need at least wxWidgets-2.9.0.
- Add -lang subpackage
- Switch build to cmake
- Spec cleanup
* Mon Dec 14 2020 Fridrich Strba <fridrich.strba@bluewin.ch>
- Update to version 2.3.2.20201016.9fd038f82
  * fix build with newer libupnp
* Mon Apr 20 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.3.2.20200131.c0c28234a
  * fix build problem with newer bfd
- Disable geoip for Tumbleweed (no longer available there)
* Wed Nov 13 2019 Dave Plater <davejplater@gmail.com>
- Use wxWidgets-nostl, this is maybe not needed but doesn't hurt.
- Remove kde4 and qt4 elements to allow Tumbleweed build, see:
  https://github.com/amule-project/amule/issues/110
* Sun Sep 22 2019 olaf@aepfle.de
- Update to version 2.3.2.20190827.2a1b09233
* Fri Aug  2 2019 Dave Plater <davejplater@gmail.com>
- Enabled wxWidgets >= 3.0.
* Mon Dec 10 2018 Javier Llorente <javier@opensuse.org>
- Update to version 2.3.2.20181119.20afd75fa
  * Bugfix: API mismatch with crypto++ 6.0.0; GH #120
- Add patch to fix build: Update to libupnp 1.8; GH #135
- Redo 0001-Fix-desktop-files.patch
* Sun Feb 26 2017 martin@pluskal.org
- Update to version 2.3.2.20161207.047a55c93
  * Changelog update
  * Update translation source
  * Update translations
  * Update french translation
  * Revert "fix a potential invalid detection for empty wxCharBuffer."
  * Do not override automake rule
  * Workaround for wxWidgets bug #17740, fixes GH issue #74
  * In VS2015 Microsoft moved std::min and std::max to algorithm
  * mslu is removed in wxMSW 3.1.0
- Add _service
* Fri Feb 17 2017 olaf@aepfle.de
- Use wxWidgets-3_0
* Tue Nov  6 2012 fisiu@opensuse.org
- Fix #PM-46: aMule fails to start on openSUSE:
  https://bugs.links2linux.org/browse/PM-46
* Thu Dec 29 2011 reddwarf@opensuse.org
- new upstream version 2.3.1
* Sat Mar 12 2011 reddwarf@opensuse.org
- use %%wx_requires in >=11.4
* Thu Mar 10 2011 javier@links2linux.de
- switch BuildRequires wxWidgets from PM to wxGTK for 11.2 and 11.3
* Wed Mar  9 2011 javier@links2linux.de
- add buildrequires libwx_gtk2u_gl-2_8-0-stl for 11.4
* Wed Mar  9 2011 javier@links2linux.de
- update buildrequires libcrypto++0-devel to libcryptopp-devel
* Wed Mar  9 2011 javier@links2linux.de
- split changelog from spec, fix file list
* Mon Oct  5 2009 Andrea Florio <andrea@links2linux,de> 2.2.6
- new upstream version 2.2.6
* Mon May 18 2009 Andrea Florio <andrea@links2linux,de> 2.2.5
- new upstream version 2.2.5
* Thu Apr 16 2009 andrea@links2linux.de
- update to upstream 2.2.4
* Mon Mar 23 2009 andrea@links2linux.de
- added upnp support
* Fri Jan  2 2009 andrea@links2linux.de
- update to upstream 2.2.3
* Sun Aug 17 2008 quentin@links2linux.de
- update to upstream 2.2.2
* Thu Jun 12 2008 quentin@links2linux.de
- update to upstream 2.2.1
- removed obsolete configure options (--disable-gsocket, --enable-unicode, --enable-utf8-systray)
* Mon Mar 24 2008 quentin@links2linux.de
- update to svn 20080324
- added geoip support
- fixed some BuildRequires
* Sat May 12 2007 detlef@links2linux.de
- update to CVS 20070507
* Wed May  3 2006 quentin@links2linux.de
- update to 2.0.2
* Tue Mar 21 2006 quentin@links2linux.de
- changed to -enable-amule-gui
* Sun Mar 19 2006 quentin@links2linux.de
- update to version 2.1.1 - bugfix release
* Sat Jan 14 2006 quentin@links2linux.de
- update to version 2.1.0 - the "I just teased you with this release till 2006" version
* Wed Jun 15 2005 quentin@links2linux.de
- update to version 2.0.3 - the "Hell 2.0.3: Now with improved daemons!" version.
- added aMule Folder Icons from AdrienV
* Thu Jun  9 2005 quentin@links2linux.de
- update to version 2.0.2
* Wed May 18 2005 quentin@links2linux.de
- update to the hotfix release, codename 'The Woops, HotFix"" version.'
* Tue May  3 2005 quentin@links2linux.de
- updated to the final release 2.0.0, codename 'The "Let's dedicate this to Tiku" version.'
* Thu Apr 21 2005 quentin@links2linux.de
- enabled the amule-daemon
- added a new desktop-icon (Crystal)
* Wed Apr  6 2005 quentin@links2linux.de
- update to rc8 on SuSE 9.3
* Mon Nov 22 2004 quentin@links2linux.de
- update to rc7 with SuSE's 9.2 wxGTK
* Tue Oct  5 2004 quentin@links2linux.de
- fixed wxWindows problems
* Mon Oct  4 2004 quentin@links2linux.de
- update to version 2.0.0rc6
* Tue Dec 30 2003 deltahf@users.sourceforge.net
- Removed statically link of libcurl, libssl and libcrypt for SuSE 8.2 and 9.0 rpms
* Thu Dec 18 2003 pure_ascii@users.sourceforge.net
- Call strip for the binaries
- Link libcurl, libssl and libcrypto statically
- better detection of wx-config
* Tue Dec 16 2003 pure_ascii@users.sourceforge.net
- Added patch to change optimisation to -Os (optimise for size)
- Fixed path for most doc files
* Sat Nov 29 2003 pure_ascii@users.sourceforge.net
- Initial revision
